Learn R Programming

MAVTgsa (version 1.3)

Wilksn: Wilk's Lambda for n-group multiple comparisons

Description

To compute Wilk's Lambda statistic for multivariate analysis of variance and multiple comparisons.

Usage

Wilksn(Y, class, type = c("Tukey", "Dunnett", "Sequence"), base = 1)

Arguments

Y
Data matrix; row is sample; each column is variable(gene).
class
Vector defining the clinical outcome of the samples.
type
Type of contrast
base
An integer to denote which group is considered the baseline group for Dunnett contrasts.

Value

Wilk's Lambdas for MANOVA and multiple comparisons are returned.

References

Frank Bretz, Torsten Hothorn and Peter Westfall (2010), Multiple Comparison Using R, CRC Press, Boca Raton

Tsai,C.A. et al. (2009) Multivariate analysis of variance test for gene set analysis. Bioinformatics, 25, 897.